@@ -10,10 +10,10 @@ no if $] > 5.017010, warnings => 'experimental::smartmatch';
 use English qw( -no_match_vars );
 local $OUTPUT_AUTOFLUSH = 1;
 
-our $VERSION = '0.25_06';
+our $VERSION = '0.25_07';
 
 BEGIN {
-	use Term::ReadKey;
+	#use Term::ReadKey;
 	use Term::ReadLine;
 	#$ENV{TERM} = 'dumb' if $OSNAME eq 'MSWin32';
 }
@@ -690,7 +690,7 @@ Debug::Client - debugger client side code for Padre, The Perl IDE.
 
 =head1 VERSION
 
-This document describes Debug::Client version: 0.25_06
+This document describes Debug::Client version: 0.25_07
 
 =head1 SYNOPSIS
 
