@@ -7,7 +7,7 @@ use English qw( -no_match_vars );
 local $OUTPUT_AUTOFLUSH = 1;
 
 BEGIN {
-	use Term::ReadKey;
+	#use Term::ReadKey;
 	use Term::ReadLine;
 	#$ENV{TERM} = 'dumb' if $OSNAME eq 'MSWin32';
 }
